@@ -17,9 +17,7 @@
 
 /* \summary: Generic Network Virtualization Encapsulation (Geneve) printer */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "netdissect-stdinc.h"
 
