@@ -16,9 +16,7 @@
 
 /* \summary: unsupported link-layer protocols printer */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "netdissect-stdinc.h"
 
