@@ -35,17 +35,12 @@
  * FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "netdissect-stdinc.h"
 
 #include <sys/stat.h>
 
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
-#endif
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -171,6 +166,23 @@ nd_printn(netdissect_options *ndo,
 	return (n == 0) ? 0 : 1;
 }
 
+/*
+ * Print a counted filename (or other ASCII string), part of
+ * the packet buffer, filtering out non-printable characters.
+ * Stop if truncated (via GET_U_1/longjmp) or after n bytes,
+ * whichever is first.
+ * The suffix comes from: j:longJmp, n:after N bytes.
+ */
+void
+nd_printjn(netdissect_options *ndo, const u_char *s, u_int n)
+{
+	while (n > 0) {
+		fn_print_char(ndo, GET_U_1(s));
+		n--;
+		s++;
+	}
+}
+
 /*
  * Print a null-padded filename (or other ASCII string), part of
  * the packet buffer, filtering out non-printable characters.
@@ -197,17 +209,21 @@ nd_printjnp(netdissect_options *ndo, const u_char *s, u_int n)
  * Print the timestamp .FRAC part (Microseconds/nanoseconds)
  */
 static void
-ts_frac_print(netdissect_options *ndo, long usec)
+ts_frac_print(netdissect_options *ndo, const struct timeval *tv)
 {
 #ifdef HAVE_PCAP_SET_TSTAMP_PRECISION
 	switch (ndo->ndo_tstamp_precision) {
 
 	case PCAP_TSTAMP_PRECISION_MICRO:
-		ND_PRINT(".%06u", (unsigned)usec);
+		ND_PRINT(".%06u", (unsigned)tv->tv_usec);
+		if ((unsigned)tv->tv_usec > ND_MICRO_PER_SEC - 1)
+			ND_PRINT(" " ND_INVALID_MICRO_SEC_STR);
 		break;
 
 	case PCAP_TSTAMP_PRECISION_NANO:
-		ND_PRINT(".%09u", (unsigned)usec);
+		ND_PRINT(".%09u", (unsigned)tv->tv_usec);
+		if ((unsigned)tv->tv_usec > ND_NANO_PER_SEC - 1)
+			ND_PRINT(" " ND_INVALID_NANO_SEC_STR);
 		break;
 
 	default:
@@ -215,7 +231,9 @@ ts_frac_print(netdissect_options *ndo, long usec)
 		break;
 	}
 #else
-	ND_PRINT(".%06u", (unsigned)usec);
+	ND_PRINT(".%06u", (unsigned)tv->tv_usec);
+	if ((unsigned)tv->tv_usec > ND_MICRO_PER_SEC - 1)
+		ND_PRINT(" " ND_INVALID_MICRO_SEC_STR);
 #endif
 }
 
@@ -225,23 +243,38 @@ ts_frac_print(netdissect_options *ndo, long usec)
  *   if date_flag == WITH_DATE print YY:MM:DD before HH:MM:SS.FRAC
  */
 static void
-ts_date_hmsfrac_print(netdissect_options *ndo, long sec, long usec,
+ts_date_hmsfrac_print(netdissect_options *ndo, const struct timeval *tv,
 		      enum date_flag date_flag, enum time_flag time_flag)
 {
-	time_t Time = sec;
 	struct tm *tm;
 	char timebuf[32];
 	const char *timestr;
+#ifdef _WIN32
+	time_t sec;
+#endif
 
-	if ((unsigned)sec & 0x80000000) {
-		ND_PRINT("[Error converting time]");
+	if (tv->tv_sec < 0) {
+		ND_PRINT("[timestamp overflow]");
 		return;
 	}
 
+#ifdef _WIN32
+	/* on Windows tv->tv_sec is a long not a 64-bit time_t. */
+	sec = tv->tv_sec;
+#endif
+
 	if (time_flag == LOCAL_TIME)
-		tm = localtime(&Time);
+#ifdef _WIN32
+		tm = localtime(&sec);
+#else
+		tm = localtime(&tv->tv_sec);
+#endif
 	else
-		tm = gmtime(&Time);
+#ifdef _WIN32
+		tm = gmtime(&sec);
+#else
+		tm = gmtime(&tv->tv_sec);
+#endif
 
 	if (date_flag == WITH_DATE) {
 		timestr = nd_format_time(timebuf, sizeof(timebuf),
@@ -252,22 +285,22 @@ ts_date_hmsfrac_print(netdissect_options *ndo, long sec, long usec,
 	}
 	ND_PRINT("%s", timestr);
 
-	ts_frac_print(ndo, usec);
+	ts_frac_print(ndo, tv);
 }
 
 /*
  * Print the timestamp - Unix timeval style, as SECS.FRAC.
  */
 static void
-ts_unix_print(netdissect_options *ndo, long sec, long usec)
+ts_unix_print(netdissect_options *ndo, const struct timeval *tv)
 {
-	if ((unsigned)sec & 0x80000000) {
-		ND_PRINT("[Error converting time]");
+	if (tv->tv_sec < 0) {
+		ND_PRINT("[timestamp overflow]");
 		return;
 	}
 
-	ND_PRINT("%u", (unsigned)sec);
-	ts_frac_print(ndo, usec);
+	ND_PRINT("%" PRId64, (int64_t)tv->tv_sec);
+	ts_frac_print(ndo, tv);
 }
 
 /*
@@ -285,8 +318,7 @@ ts_print(netdissect_options *ndo,
 	switch (ndo->ndo_tflag) {
 
 	case 0: /* Default */
-		ts_date_hmsfrac_print(ndo, tvp->tv_sec, tvp->tv_usec,
-				      WITHOUT_DATE, LOCAL_TIME);
+		ts_date_hmsfrac_print(ndo, tvp, WITHOUT_DATE, LOCAL_TIME);
 		ND_PRINT(" ");
 		break;
 
@@ -294,7 +326,7 @@ ts_print(netdissect_options *ndo,
 		break;
 
 	case 2: /* Unix timeval style */
-		ts_unix_print(ndo, tvp->tv_sec, tvp->tv_usec);
+		ts_unix_print(ndo, tvp);
 		ND_PRINT(" ");
 		break;
 
@@ -325,8 +357,7 @@ ts_print(netdissect_options *ndo,
 			netdissect_timevalsub(tvp, &tv_ref, &tv_result, nano_prec);
 
 		ND_PRINT((negative_offset ? "-" : " "));
-		ts_date_hmsfrac_print(ndo, tv_result.tv_sec, tv_result.tv_usec,
-				      WITHOUT_DATE, UTC_TIME);
+		ts_date_hmsfrac_print(ndo, &tv_result, WITHOUT_DATE, UTC_TIME);
 		ND_PRINT(" ");
 
                 if (ndo->ndo_tflag == 3)
@@ -334,8 +365,7 @@ ts_print(netdissect_options *ndo,
 		break;
 
 	case 4: /* Date + Default */
-		ts_date_hmsfrac_print(ndo, tvp->tv_sec, tvp->tv_usec,
-				      WITH_DATE, LOCAL_TIME);
+		ts_date_hmsfrac_print(ndo, tvp, WITH_DATE, LOCAL_TIME);
 		ND_PRINT(" ");
 		break;
 	}
@@ -459,19 +489,14 @@ void nd_print_invalid(netdissect_options *ndo)
 
 int
 print_unknown_data(netdissect_options *ndo, const u_char *cp,
-                   const char *ident, u_int len)
+                   const char *indent, u_int len)
 {
-	u_int len_to_print;
-
-	len_to_print = len;
 	if (!ND_TTEST_LEN(cp, 0)) {
-		ND_PRINT("%sDissector error: print_unknown_data called with pointer past end of packet",
-		    ident);
+		ND_PRINT("%sDissector error: %s() called with pointer past end of packet",
+		    indent, __func__);
 		return(0);
 	}
-	if (ND_BYTES_AVAILABLE_AFTER(cp) < len_to_print)
-		len_to_print = ND_BYTES_AVAILABLE_AFTER(cp);
-	hex_print(ndo, ident, cp, len_to_print);
+	hex_print(ndo, indent, cp, ND_MIN(len, ND_BYTES_AVAILABLE_AFTER(cp)));
 	return(1); /* everything is ok */
 }
 
@@ -480,7 +505,7 @@ print_unknown_data(netdissect_options *ndo, const u_char *cp,
  */
 static const char *
 tok2strbuf(const struct tok *lp, const char *fmt,
-	   u_int v, char *buf, size_t bufsize)
+	   const u_int v, char *buf, const size_t bufsize)
 {
 	if (lp != NULL) {
 		while (lp->s != NULL) {
@@ -502,8 +527,7 @@ tok2strbuf(const struct tok *lp, const char *fmt,
  * in round-robin fashion.
  */
 const char *
-tok2str(const struct tok *lp, const char *fmt,
-	u_int v)
+tok2str(const struct tok *lp, const char *fmt, const u_int v)
 {
 	static char buf[4][TOKBUFSIZE];
 	static int idx = 0;
@@ -524,7 +548,7 @@ tok2str(const struct tok *lp, const char *fmt,
  */
 static char *
 bittok2str_internal(const struct tok *lp, const char *fmt,
-	   u_int v, const char *sep)
+		    const u_int v, const char *sep)
 {
         static char buf[1024+1]; /* our string buffer */
         char *bufp = buf;
@@ -564,8 +588,7 @@ bittok2str_internal(const struct tok *lp, const char *fmt,
  * this is useful for parsing bitfields, the output strings are not separated.
  */
 char *
-bittok2str_nosep(const struct tok *lp, const char *fmt,
-	   u_int v)
+bittok2str_nosep(const struct tok *lp, const char *fmt, const u_int v)
 {
     return (bittok2str_internal(lp, fmt, v, ""));
 }
@@ -575,8 +598,7 @@ bittok2str_nosep(const struct tok *lp, const char *fmt,
  * this is useful for parsing bitfields, the output strings are comma separated.
  */
 char *
-bittok2str(const struct tok *lp, const char *fmt,
-	   u_int v)
+bittok2str(const struct tok *lp, const char *fmt, const u_int v)
 {
     return (bittok2str_internal(lp, fmt, v, ", "));
 }
@@ -588,8 +610,7 @@ bittok2str(const struct tok *lp, const char *fmt,
  * correct for bounds-checking.
  */
 const char *
-tok2strary_internal(const char **lp, int n, const char *fmt,
-	int v)
+tok2strary_internal(const char **lp, int n, const char *fmt, const int v)
 {
 	static char buf[TOKBUFSIZE];
 
@@ -622,7 +643,7 @@ uint2tokary_internal(const struct uint_tokary dict[], const size_t size,
  */
 
 int
-mask2plen(uint32_t mask)
+mask2plen(const uint32_t mask)
 {
 	const uint32_t bitmasks[33] = {
 		0x00000000,
@@ -688,9 +709,9 @@ mask62plen(const u_char *mask)
  * either a space character at the beginning of the line (this
  * includes a blank line) or no more tokens remaining on the line.
  */
-static int
+static u_int
 fetch_token(netdissect_options *ndo, const u_char *pptr, u_int idx, u_int len,
-    u_char *tbuf, size_t tbuflen)
+	    u_char *tbuf, size_t tbuflen)
 {
 	size_t toklen = 0;
 	u_char c;
@@ -814,11 +835,10 @@ print_txt_line(netdissect_options *ndo, const char *prefix,
 
 	/*
 	 * All printable ASCII, but no line ending after that point
-	 * in the buffer; treat this as if it were truncated.
+	 * in the buffer.
 	 */
 	linelen = idx - startidx;
 	ND_PRINT("%s%.*s", prefix, (int)linelen, pptr + startidx);
-	nd_print_trunc(ndo);
 	return (0);
 
 print:
